@@ -2,12 +2,32 @@ import os
 import sys
 
 CLI_CONFIG = {
-    "log_file": {"dyne": "__cli__", "subcommands": ["_global_"]},
-    "log_level": {"dyne": "__cli__", "subcommands": ["_global_"]},
-    "log_fmt_logfile": {"dyne": "__cli__", "subcommands": ["_global_"]},
-    "log_fmt_console": {"dyne": "__cli__", "subcommands": ["_global_"]},
-    "log_datefmt": {"dyne": "__cli__", "subcommands": ["_global_"]},
-    "log_plugin": {"dyne": "__cli__", "subcommands": ["_global_"]},
+    "log_file": {"dyne": "__cli__", "os": "POP_LOG_FILE", "subcommands": ["_global_"]},
+    "log_level": {
+        "dyne": "__cli__",
+        "os": "POP_LOG_LEVEL",
+        "subcommands": ["_global_"],
+    },
+    "log_fmt_logfile": {
+        "dyne": "__cli__",
+        "os": "POP_LOG_FMT_LOGFILE",
+        "subcommands": ["_global_"],
+    },
+    "log_fmt_console": {
+        "dyne": "__cli__",
+        "os": "POP_LOG_FMT_CONSOLE",
+        "subcommands": ["_global_"],
+    },
+    "log_datefmt": {
+        "dyne": "__cli__",
+        "os": "POP_LOG_DATEFMT",
+        "subcommands": ["_global_"],
+    },
+    "log_plugin": {
+        "dyne": "__cli__",
+        "os": "POP_LOG_PLUGIN",
+        "subcommands": ["_global_"],
+    },
     "log_handler_options": {
         "dyne": "__cli__",
         "subcommands": ["_global_"],
@@ -26,6 +46,13 @@ CLI_CONFIG = {
         "action": "store_true",
         "help": "Output a config template for this command",
     },
+    "versions_report": {
+        "dyne": "__cli__",
+        "subcommands": ["_global_"],
+        "default": False,
+        "action": "store_true",
+        "help": "Output a version report for reporting bugs",
+    },
 }
 
 CONFIG = {
