@@ -50,7 +50,8 @@ def find_configs(hub, sources: List[str]):
     for source in sources:
         try:
             path, data = hub.config.dirs.import_conf(source)
-        except ImportError:
+        except ImportError as e:
+            hub.log.error(f"Could not find conf.py for '{source}': {e}")
             continue
         dict_tools.update.update(raw, data)
     return raw
