@@ -33,6 +33,8 @@ def setup(hub, conf):
     )
     if ":" in conf["log_file"]:
         host, port = conf["log_file"].split(":")
+        if port:
+            port = int(port)
     else:
         host = conf["log_file"]
         port = None
