@@ -5,17 +5,15 @@ Define the yaml loader interface
 try:
     import toml
 
-    HAS_TOML = True
-except ImportError:
-    HAS_TOML = False
+    HAS_TOML = (True,)
+except ImportError as e:
+    HAS_TOML = False, str(e)
 
 __virtualname__ = "toml"
 
 
 def __virtual__(hub):
-    if HAS_TOML:
-        return True
-    return (False, "TOML could not be loaded")
+    return HAS_TOML
 
 
 def load(hub, path):
@@ -23,8 +21,8 @@ def load(hub, path):
     use toml to read in a file
     """
     try:
-        with open(path, "rb") as fp_:
-            return toml.load(fp_.read())
+        with open(path) as fp_:
+            return toml.loads(fp_.read())
     except FileNotFoundError:
         pass
     return {}
